/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.commons.messaging.mail;

import jakarta.mail.MessagingException;
import jakarta.mail.internet.MimeMessage;

import org.jetbrains.annotations.NotNull;
import org.osgi.annotation.versioning.ProviderType;

/**
 * Provider for message identifiers.
 *
 * @see MimeMessage
 */
@ProviderType
public interface MessageIdProvider {

    /**
     * Provides an identifier for given message.
     *
     * @param message the message to provide an identifier for
     * @return the message identifier
     * @throws MessagingException if providing an identifier fails
     * @see MimeMessage#getMessageID()
     */
    public abstract @NotNull String getMessageId(@NotNull final MimeMessage message) throws MessagingException;

}
